
# Type: defining_slots


The combination of is a plus defining slots form a genus-differentia definition, or the set of necessary and sufficient conditions that can be transformed into an OWL equivalence axiom

URI: [meta:defining_slots](https://w3id.org/biolink/biolinkml/meta/defining_slots)


## Domain and Range

[ClassDefinition](ClassDefinition.md) ->  <sub>0..*</sub> [SlotDefinition](SlotDefinition.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
